# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import enum
import typing
import uuid

import bleak_winrt._winrt as _winrt
try:
    import bleak_winrt.windows.devices.bluetooth
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.bluetooth.advertisement
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.bluetooth.genericattributeprofile
except Exception:
    pass

try:
    import bleak_winrt.windows.devices.bluetooth.rfcomm
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation
except Exception:
    pass

try:
    import bleak_winrt.windows.foundation.collections
except Exception:
    pass

try:
    import bleak_winrt.windows.networking.sockets
except Exception:
    pass

try:
    import bleak_winrt.windows.storage.streams
except Exception:
    pass

class BluetoothEventTriggeringMode(enum.IntEnum):
    SERIAL = 0
    BATCH = 1
    KEEP_LATEST = 2

class BluetoothLEAdvertisementPublisherTriggerDetails(_winrt.winrt_base):
    ...
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError
    status: bleak_winrt.windows.devices.bluetooth.advertisement.BluetoothLEAdvertisementPublisherStatus
    selected_transmit_power_level_in_d_bm: bleak_winrt.windows.foundation.IReference[int]

class BluetoothLEAdvertisementWatcherTriggerDetails(_winrt.winrt_base):
    ...
    advertisements: bleak_winrt.windows.foundation.collections.IVectorView[bleak_winrt.windows.devices.bluetooth.advertisement.BluetoothLEAdvertisementReceivedEventArgs]
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError
    signal_strength_filter: bleak_winrt.windows.devices.bluetooth.BluetoothSignalStrengthFilter

class GattCharacteristicNotificationTriggerDetails(_winrt.winrt_base):
    ...
    characteristic: bleak_winrt.windows.devices.bluetooth.genericattributeprofile.GattCharacteristic
    value: bleak_winrt.windows.storage.streams.IBuffer
    error: bleak_winrt.windows.devices.bluetooth.BluetoothError
    event_triggering_mode: BluetoothEventTriggeringMode
    value_changed_events: bleak_winrt.windows.foundation.collections.IVectorView[bleak_winrt.windows.devices.bluetooth.genericattributeprofile.GattValueChangedEventArgs]

class GattServiceProviderConnection(_winrt.winrt_base):
    ...
    service: bleak_winrt.windows.devices.bluetooth.genericattributeprofile.GattLocalService
    trigger_id: str
    all_services: bleak_winrt.windows.foundation.collections.IMapView[str, GattServiceProviderConnection]
    def start() -> None:
        ...

class GattServiceProviderTriggerDetails(_winrt.winrt_base):
    ...
    connection: GattServiceProviderConnection

class RfcommConnectionTriggerDetails(_winrt.winrt_base):
    ...
    incoming: bool
    remote_device: bleak_winrt.windows.devices.bluetooth.BluetoothDevice
    socket: bleak_winrt.windows.networking.sockets.StreamSocket

class RfcommInboundConnectionInformation(_winrt.winrt_base):
    ...
    service_capabilities: bleak_winrt.windows.devices.bluetooth.BluetoothServiceCapabilities
    sdp_record: bleak_winrt.windows.storage.streams.IBuffer
    local_service_id: bleak_winrt.windows.devices.bluetooth.rfcomm.RfcommServiceId

class RfcommOutboundConnectionInformation(_winrt.winrt_base):
    ...
    remote_service_id: bleak_winrt.windows.devices.bluetooth.rfcomm.RfcommServiceId

