// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.211028.7

#pragma once
#ifndef WINRT_Windows_Devices_Adc_Provider_2_H
#define WINRT_Windows_Devices_Adc_Provider_2_H
#include "winrt/impl/Windows.Devices.Adc.Provider.1.h"
WINRT_EXPORT namespace winrt::Windows::Devices::Adc::Provider
{
}
#endif
