// WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

#pragma once

#include "pybase.h"

#if __has_include("py.Windows.Devices.Bluetooth.h")
#include "py.Windows.Devices.Bluetooth.h"
#endif

#if __has_include("py.Windows.Devices.Bluetooth.Advertisement.h")
#include "py.Windows.Devices.Bluetooth.Advertisement.h"
#endif

#if __has_include("py.Windows.Devices.Bluetooth.GenericAttributeProfile.h")
#include "py.Windows.Devices.Bluetooth.GenericAttributeProfile.h"
#endif

#if __has_include("py.Windows.Devices.Bluetooth.Rfcomm.h")
#include "py.Windows.Devices.Bluetooth.Rfcomm.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Networking.Sockets.h")
#include "py.Windows.Networking.Sockets.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

#include <winrt/Windows.Devices.Bluetooth.Background.h>

namespace py::proj::Windows::Devices::Bluetooth::Background
{}

namespace py::impl::Windows::Devices::Bluetooth::Background
{}

namespace py::wrapper::Windows::Devices::Bluetooth::Background
{
    using BluetoothLEAdvertisementPublisherTriggerDetails = py::winrt_wrapper<winrt::Windows::Devices::Bluetooth::Background::BluetoothLEAdvertisementPublisherTriggerDetails>;
    using BluetoothLEAdvertisementWatcherTriggerDetails = py::winrt_wrapper<winrt::Windows::Devices::Bluetooth::Background::BluetoothLEAdvertisementWatcherTriggerDetails>;
    using GattCharacteristicNotificationTriggerDetails = py::winrt_wrapper<winrt::Windows::Devices::Bluetooth::Background::GattCharacteristicNotificationTriggerDetails>;
    using GattServiceProviderConnection = py::winrt_wrapper<winrt::Windows::Devices::Bluetooth::Background::GattServiceProviderConnection>;
    using GattServiceProviderTriggerDetails = py::winrt_wrapper<winrt::Windows::Devices::Bluetooth::Background::GattServiceProviderTriggerDetails>;
    using RfcommConnectionTriggerDetails = py::winrt_wrapper<winrt::Windows::Devices::Bluetooth::Background::RfcommConnectionTriggerDetails>;
    using RfcommInboundConnectionInformation = py::winrt_wrapper<winrt::Windows::Devices::Bluetooth::Background::RfcommInboundConnectionInformation>;
    using RfcommOutboundConnectionInformation = py::winrt_wrapper<winrt::Windows::Devices::Bluetooth::Background::RfcommOutboundConnectionInformation>;
}

namespace py
{
    template<>
    struct winrt_type<winrt::Windows::Devices::Bluetooth::Background::BluetoothLEAdvertisementPublisherTriggerDetails>
    {
        static PyTypeObject* python_type;
        static PyTypeObject* get_python_type() { return python_type; }
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::Bluetooth::Background::BluetoothLEAdvertisementWatcherTriggerDetails>
    {
        static PyTypeObject* python_type;
        static PyTypeObject* get_python_type() { return python_type; }
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::Bluetooth::Background::GattCharacteristicNotificationTriggerDetails>
    {
        static PyTypeObject* python_type;
        static PyTypeObject* get_python_type() { return python_type; }
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::Bluetooth::Background::GattServiceProviderConnection>
    {
        static PyTypeObject* python_type;
        static PyTypeObject* get_python_type() { return python_type; }
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::Bluetooth::Background::GattServiceProviderTriggerDetails>
    {
        static PyTypeObject* python_type;
        static PyTypeObject* get_python_type() { return python_type; }
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::Bluetooth::Background::RfcommConnectionTriggerDetails>
    {
        static PyTypeObject* python_type;
        static PyTypeObject* get_python_type() { return python_type; }
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::Bluetooth::Background::RfcommInboundConnectionInformation>
    {
        static PyTypeObject* python_type;
        static PyTypeObject* get_python_type() { return python_type; }
    };

    template<>
    struct winrt_type<winrt::Windows::Devices::Bluetooth::Background::RfcommOutboundConnectionInformation>
    {
        static PyTypeObject* python_type;
        static PyTypeObject* get_python_type() { return python_type; }
    };

}
