# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-alpha.6

import setuptools

setuptools.setup(
    name = "bleak_winrt",
    version = "1.0a0",
    description="Generated Python/WinRT package",
    license="MIT",
    url="http://github.com/Microsoft/xlang",
    package_data={ "bleak_winrt":["_winrt.pyd", "py.typed"] },
    packages = setuptools.find_namespace_packages(where='.', include=("bleak_winrt*")))
